@@ -1,3 +1,6 @@
+"""
+One Piece API wrapper (french data)
+"""
 from .functions import *
 from .interface import API
 
@@ -5,6 +8,10 @@ __all__ = [
     "API",
     "episode_by_id",
     "episode_by_title",
+    "episode_by_saga_id",
+    "episode_by_arc_id",
+    "episode_by_arc_title",
+    "episode_by_saga_title",
     "count_episodes",
     "movie_by_id",
     "movie_by_title",
@@ -16,7 +23,7 @@ __all__ = [
     "chapter_by_title",
     "count_chapters",
     "arc_by_id",
-    # "arc_by_title",
+    "arc_by_title",
     "arc_by_saga_id",
     "count_arcs",
     "saga_by_id",
